Trait winit::platform::unix::EventLoopWindowTargetExtUnix
source · pub trait EventLoopWindowTargetExtUnix {
// Required methods
fn is_wayland(&self) -> bool;
fn is_x11(&self) -> bool;
fn wayland_display(&self) -> Option<*mut c_void>;
}Expand description
Additional methods on EventLoopWindowTarget that are specific to Unix.
Required Methods
sourcefn is_wayland(&self) -> bool
fn is_wayland(&self) -> bool
True if the EventLoopWindowTarget uses Wayland.
sourcefn is_x11(&self) -> bool
fn is_x11(&self) -> bool
True if the EventLoopWindowTarget uses X11.
sourcefn wayland_display(&self) -> Option<*mut c_void>
fn wayland_display(&self) -> Option<*mut c_void>
Returns a pointer to the wl_display object of wayland that is used by this
EventLoopWindowTarget.
Returns None if the EventLoop doesn’t use wayland (if it uses xlib for example).
The pointer will become invalid when the winit EventLoop is destroyed.